summaryrefslogtreecommitdiffstats
path: root/kooka/kocrocrad.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:21:13 -0600
committerSlávek Banko <slavek.banko@axis.cz>2012-06-03 19:30:04 +0200
commit79e5d6be76392920c148aa615d9e3504f3388996 (patch)
treebc713fbfa18e2c962f2f1ea8adf9ec5c1ac187ee /kooka/kocrocrad.cpp
parent5027dfec5092217f70492dd6712059e46b21d003 (diff)
downloadtdegraphics-79e5d6be76392920c148aa615d9e3504f3388996.tar.gz
tdegraphics-79e5d6be76392920c148aa615d9e3504f3388996.zip
Rename obsolete tq methods to standard names
(cherry picked from commit ebbee358abafa1b5166404c6fe5cc44ae2837a57)
Diffstat (limited to 'kooka/kocrocrad.cpp')
-rw-r--r--kooka/kocrocrad.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kooka/kocrocrad.cpp b/kooka/kocrocrad.cpp
index b9365767..86796341 100644
--- a/kooka/kocrocrad.cpp
+++ b/kooka/kocrocrad.cpp
@@ -129,7 +129,7 @@ EngineError ocradDialog::setupGui()
else
m_ocrCmd = res;
/** tqlayout detection button **/
conf->setGroup( CFG_GROUP_OCRAD );
int layoutDetect = conf->readNumEntry( CFG_OCRAD_LAYOUT_DETECTION, 0 );
kdDebug(28000) << "Layout detection from config: " << layoutDetect << endl;
@@ -137,7 +137,7 @@ EngineError ocradDialog::setupGui()
(void) new KSeparator( KSeparator::HLine, page);
TQHBox *hb1 = new TQHBox(page);
hb1->setSpacing( KDialog::spacingHint() );
- (void) new TQLabel( i18n("OCRAD tqlayout analysis mode: "), hb1);
+ (void) new TQLabel( i18n("OCRAD layout analysis mode: "), hb1);
m_layoutMode = new TQComboBox(hb1);
m_layoutMode->insertItem(i18n("No Layout Detection"), 0 );
m_layoutMode->insertItem(i18n("Column Detection"), 1 );
@@ -129,7 +129,7 @@ EngineError ocradDialog::setupGui()
else
m_ocrCmd = res;
- /** tqlayout detection button **/
+ /** layout detection button **/
conf->setGroup( CFG_GROUP_OCRAD );
int layoutDetect = conf->readNumEntry( CFG_OCRAD_LAYOUT_DETECTION, 0 );